@@ -2,7 +2,7 @@ import os
 import re
 
 # 版本号  setup.py  ming.py 引用  每次发布 版本+1
-ming_global_version = 2.9
+ming_global_version = 2.13
 
 
 def getVersion():
@@ -39,6 +39,12 @@ tools_dependency_info_arr = [
     # ToolsDependency('showError', '测试错误情况', 'test'),
 ]
 
+# 配置目录存放在 用户根目录
+db_dir = '{}/.jiuming-tools/config/db'.format(os.path.expanduser('~'))
+if not os.path.exists(db_dir):
+    os.makedirs(db_dir)
+
+
 # 配置目录存放在 用户根目录
 root_config_dir = '{}/.jiuming-tools'.format(os.path.expanduser('~'))
 if not os.path.exists(root_config_dir):
@@ -63,3 +69,5 @@ if not os.path.exists(private_key_default_file):
 compile_ip = re.compile('^((25[0-5]|2[0-4]\d|[01]?\d\d?)\.){3}(25[0-5]|2[0-4]\d|[01]?\d\d?)$')
 compile_host_mame = re.compile('^[a-zA-Z0-9][-a-zA-Z0-9]{0,62}(\.[a-zA-Z0-9][-a-zA-Z0-9]{0,62})+\.?$')
 compile_tun_value = re.compile('^[a-zA-Z0-9]{0,62}:[a-zA-Z0-9]{0,62}$')
+
+
